(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    186091,       3637]
NotebookOptionsPosition[    180678,       3509]
NotebookOutlinePosition[    181058,       3526]
CellTagsIndexPosition[    181015,       3523]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Note: run \[OpenCurlyDoubleQuote]full oscillator.nb\
\[CloseCurlyDoubleQuote] first, which defines the mechanistic model.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.709407982392235*^9, 
  3.709408049672308*^9}},ExpressionUUID->"82ccb513-2073-4b96-a27a-\
901785837b97"],

Cell[CellGroupData[{

Cell["Define Model", "Subsection",
 CellChangeTimes->{{3.658176429855425*^9, 3.658176448864417*^9}, {
  3.659730300271228*^9, 
  3.659730301854652*^9}},ExpressionUUID->"ab971b2c-f52a-4373-8a41-\
45d92ff3f054"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tmax", " ", "=", " ", 
    RowBox[{"120", "*", "60", "*", "60"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"simulation", " ", "time", " ", "in", " ", "seconds"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7094096699054317`*^9, 3.7094096913206472`*^9}, {
  3.709409723092749*^9, 
  3.709409728618647*^9}},ExpressionUUID->"cb039ef8-c519-44e5-9fa7-\
d84d9715295c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Instantiate", " ", "autocatalytic", " ", "system", " ", "A"}], 
     "+", "C"}], "\[Rule]", 
    RowBox[{"A", "+", "A"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"rlsys", "=", "\[IndentingNewLine]", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"bibi", "[", 
        RowBox[{
        "a", ",", "c", ",", "a", ",", "a", ",", "31", ",", "32", ",", " ", 
         "kfwd1ACApi2", ",", "kbackACApi2", ",", "kfwd2ACApi2", ",", 
         "kfwd1CApAq", ",", "kbackCApAq", ",", " ", "kfwd2CApAq", ",", 
         "kleakCApAq", ",", "trunctailsfrac", ",", "leakfrac", ",", "0"}], 
        "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Reaction", " ", "of", " ", "signal", " ", "A", " ", 
         RowBox[{"(", 
          RowBox[{"the", " ", "autocatalyst"}], ")"}], " ", "with", " ", 
         "threshold"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"rxn", "[", 
          RowBox[{
           RowBox[{"sa", "+", "thresh"}], ",", "threshsig", ",", 
           RowBox[{"7.4", " ", 
            RowBox[{"10", "^", "5"}]}]}], " ", 
          RowBox[{"(*", 
           RowBox[{
           "rate", " ", "constant", " ", "from", " ", "Table", " ", "S3"}], 
           "*)"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"sa", ",", 
           RowBox[{"sigList", "[", "a", "]"}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"conc", "[", 
        RowBox[{
         RowBox[{"First", "[", 
          RowBox[{"sigList", "[", "c", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "trunctailsfrac"}], ")"}], "50", "*", "cx"}]}], 
        "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"conc", "[", 
        RowBox[{"thresh", ",", 
         RowBox[{"th0", "*", "cx"}]}], "]"}]}], "   ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"initial", " ", "amount", " ", "of", " ", "threshold"}], ",", 
        " ", 
        RowBox[{"which", " ", "will", " ", "be", " ", "fitted"}]}], " ", 
       "*)"}], "\[IndentingNewLine]", "}"}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.7094078315152397`*^9, 3.709407933958334*^9}, {
   3.709409405872806*^9, 3.709409413372938*^9}, {3.7111520634813232`*^9, 
   3.7111521351084433`*^9}, {3.711152243368878*^9, 3.711152248735188*^9}, {
   3.711152288593091*^9, 3.711152297987973*^9}, {3.7111525086230917`*^9, 
   3.7111525125480413`*^9}, {3.711191415336666*^9, 3.71119141580424*^9}, {
   3.711194041488337*^9, 3.711194068611812*^9}, {3.7111941566177387`*^9, 
   3.7111941823052177`*^9}, {3.711194481095977*^9, 3.711194481457817*^9}, {
   3.71123709882197*^9, 3.711237142073159*^9}, {3.7112373968926353`*^9, 
   3.711237412948759*^9}, {3.7112374694266987`*^9, 3.7112374949812737`*^9}, {
   3.7116507930333033`*^9, 3.711650840943121*^9}, {3.711650876915868*^9, 
   3.711650910454282*^9}, 
   3.711651149504547*^9},ExpressionUUID->"a92b2572-cc46-4eb5-a7f1-\
4e7773ea2e89"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Move", " ", "leak", " ", "reactions", " ", "to", " ", "a", " ", 
    "separate", " ", "system", " ", "called", " ", 
    RowBox[{"leakrxns", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"leakrxns", "=", 
     RowBox[{"Cases", "[", 
      RowBox[{"rlsys", ",", 
       RowBox[{
        RowBox[{"leak", "[", "r_", "]"}], "\[RuleDelayed]", "r"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rsys", "=", 
     RowBox[{"DeleteCases", "[", 
      RowBox[{"rlsys", ",", 
       RowBox[{"leak", "[", "_", "]"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.6598228319544153`*^9, 3.659822888583411*^9}, 
   3.659823055099975*^9, {3.6598231171354856`*^9, 3.6598231459993563`*^9}, {
   3.659823532430832*^9, 3.659823549862043*^9}, {3.659825254084384*^9, 
   3.659825282872611*^9}, {3.659825316373501*^9, 3.659825346735729*^9}, {
   3.6598253895774193`*^9, 3.659825457073307*^9}, {3.659825616700481*^9, 
   3.6598256177264023`*^9}, {3.659825701365254*^9, 3.659825724624002*^9}, {
   3.7093168289085293`*^9, 3.709316831857533*^9}, {3.709317151013917*^9, 
   3.709317161758485*^9}, {3.7093173621605473`*^9, 3.7093173754938107`*^9}, {
   3.709317724518824*^9, 3.709317727799419*^9}, {3.7094068352673903`*^9, 
   3.709406882224427*^9}},ExpressionUUID->"d8d00205-bc39-4b99-8087-\
ac5a0e9dfe71"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "add", " ", "occlusion", " ", "reactions", " ", "to", " ", "the", " ", 
    "reaction", " ", "system"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"occsys", "=", 
     RowBox[{"generateOcclusionReactions", "[", "rsys", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"roccsys", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Join", "[", 
       RowBox[{"rsys", ",", "occsys"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.6597317597396107`*^9, {3.6598237820366783`*^9, 3.659823784857699*^9}, {
   3.659823964236257*^9, 3.659823991314577*^9}, {3.709408089280373*^9, 
   3.709408089545065*^9}},ExpressionUUID->"bf8e5671-d021-422f-8666-\
182ec7cb97ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Add", " ", "leak", " ", "reactions", " ", "to", " ", "the", " ", 
    "reaction", " ", 
    RowBox[{"system", ".", " ", "simsys"}], " ", "is", " ", "the", " ", 
    "final", " ", 
    RowBox[{"model", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"leakoccsys", "=", 
     RowBox[{"generateLeakReactions", "[", 
      RowBox[{"roccsys", ",", "leakrxns"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"simsys", "=", 
     RowBox[{"Join", "[", 
      RowBox[{"roccsys", ",", "leakoccsys"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.659823214788475*^9, 3.659823244411786*^9}, {
  3.659823279510663*^9, 3.6598232843355103`*^9}, {3.6598233252975273`*^9, 
  3.659823370141786*^9}, {3.659823447259267*^9, 3.659823496617239*^9}, {
  3.659823737618891*^9, 3.6598237645918694`*^9}, {3.6598238024821653`*^9, 
  3.659823823189851*^9}, {3.6598240494241667`*^9, 3.659824082806555*^9}, {
  3.659825642832258*^9, 3.65982564338722*^9}, {3.709318514571088*^9, 
  3.709318521312364*^9}, {3.709408110970194*^9, 
  3.709408111174138*^9}},ExpressionUUID->"a6ca6dfc-a89f-4470-bb31-\
8e823d1c8ec3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load Data", "Subsection",
 CellChangeTimes->{{3.658176429855425*^9, 3.65817644173873*^9}, {
  3.659880716838876*^9, 
  3.659880717189623*^9}},ExpressionUUID->"68393eb1-ea46-43a7-913b-\
3202929222bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.658131141623652*^9, 
  3.658131155009132*^9}},ExpressionUUID->"6a5a0f48-6ae3-45ad-828a-\
675ba719404d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dataRaw", "[", "1", "]"}], "=", 
   RowBox[{
   "Import", "[", "\"\<AutocatalystData/ACAA_sample1.csv\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.658131178304463*^9, 3.65813119303001*^9}, {
   3.658131246356493*^9, 3.65813128712528*^9}, {3.658131591863312*^9, 
   3.6581315919378233`*^9}, {3.65817753754565*^9, 3.658177540868285*^9}, {
   3.6581834921092987`*^9, 3.6581835170279617`*^9}, 3.660330129709559*^9, 
   3.663078426407407*^9, {3.663078622344153*^9, 3.6630786231452007`*^9}, {
   3.709409061828311*^9, 3.7094090621556807`*^9}, {3.7111336739234743`*^9, 
   3.71113367665018*^9}, {3.711650950603299*^9, 
   3.711650951401952*^9}},ExpressionUUID->"baf9529e-b846-47dd-abdc-\
d83e8664b5a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dataRaw", "[", "2", "]"}], "=", 
   RowBox[{
   "Import", "[", "\"\<AutocatalystData/ACAA_sample2.csv\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.658131178304463*^9, 3.65813119303001*^9}, {
   3.658131246356493*^9, 3.65813128712528*^9}, {3.658131591863312*^9, 
   3.6581315919378233`*^9}, {3.65817753754565*^9, 3.658177540868285*^9}, {
   3.6581834921092987`*^9, 3.658183520846836*^9}, 3.660330131226368*^9, 
   3.6630784314332743`*^9, {3.663078626951226*^9, 3.663078627451118*^9}, {
   3.70940906458456*^9, 3.709409064906732*^9}, {3.711133682764121*^9, 
   3.711133683167927*^9}, 
   3.711650954499909*^9},ExpressionUUID->"fde57c34-2a28-4d15-bf77-\
717135e25564"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dataRaw", "[", "3", "]"}], "=", 
   RowBox[{
   "Import", "[", "\"\<AutocatalystData/ACAA_sample3.csv\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.658131178304463*^9, 3.65813119303001*^9}, {
   3.658131246356493*^9, 3.65813128712528*^9}, {3.658131591863312*^9, 
   3.6581315919378233`*^9}, {3.65817753754565*^9, 3.658177540868285*^9}, {
   3.6581834921092987`*^9, 3.6581835231363487`*^9}, 3.6603301325516367`*^9, 
   3.6630784350030518`*^9, {3.663078630714157*^9, 3.663078631034123*^9}, {
   3.66307867975381*^9, 3.6630786798053427`*^9}, {3.709409066577586*^9, 
   3.709409066905676*^9}, {3.711133686326939*^9, 3.711133686682982*^9}, {
   3.711152550908545*^9, 3.711152550962481*^9}, 
   3.711650955643641*^9},ExpressionUUID->"afb1a695-a8cb-4ff9-a79f-\
5330dc963fa1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"data", "[", "s", "]"}], "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"dataRaw", "[", "s", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"dataRaw", "[", "s", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"dataRaw", "[", "s", "]"}], "]"}]}], "}"}]}], "]"}]}], ",", 
    
    RowBox[{"{", 
     RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.658131528011211*^9, 3.6581316258231277`*^9}, {
   3.658177544852881*^9, 3.658177552814197*^9}, {3.6581818141205893`*^9, 
   3.658181816969986*^9}, {3.658183561408594*^9, 3.6581836163321133`*^9}, 
   3.658184168799732*^9, {3.658253653079525*^9, 3.658253653231358*^9}, {
   3.663078440975091*^9, 
   3.663078444268375*^9}},ExpressionUUID->"c595274d-e479-454f-bea9-\
4e9ad54a215d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fitting", "Subsection",
 CellChangeTimes->{{3.658176429855425*^9, 3.65817644173873*^9}, {
  3.6581796541136227`*^9, 3.658179657951417*^9}, {3.6582390424555902`*^9, 
  3.658239043073346*^9}},ExpressionUUID->"57116881-009a-469b-8554-\
e5ab182e429f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"parameterizedTrajectories", "[", 
   RowBox[{
   "trunctailsfracArg_", ",", "leakfracArg_", ",", " ", "logkrArg_", ",", 
    "th0Arg_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "set", " ", "temporary", " ", "values", " ", "of", " ", "global", " ", 
     "symbols", " ", "using", " ", "Block"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"trunctailsfrac", "=", "trunctailsfracArg"}], ",", 
      RowBox[{"leakfrac", "=", "leakfracArg"}], ",", 
      RowBox[{"kr", " ", "=", " ", 
       RowBox[{"10", "^", "logkrArg"}]}], ",", 
      RowBox[{"th0", "=", "th0Arg"}]}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sol", "=", 
      RowBox[{"SimulateRxnsys", "[", 
       RowBox[{"simsys", ",", "tmax"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Plus", "@@", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"t", "*", "60", "*", "60"}], "]"}], "&"}], "/@", 
            RowBox[{"SpeciesInRxnsys", "[", 
             RowBox[{"simsys", ",", 
              RowBox[{
               RowBox[{"helper", "[", 
                RowBox[{"a", ",", "a", ",", "_"}], "]"}], "|", 
               RowBox[{"cathelper", "[", 
                RowBox[{"a", ",", "a", ",", "_"}], "]"}], "|", 
               RowBox[{"occ", "[", 
                RowBox[{"___", ",", 
                 RowBox[{"helper", "[", 
                  RowBox[{"a", ",", "a", ",", "_"}], "]"}], ",", "___"}], 
                "]"}], "|", 
               RowBox[{"occ", "[", 
                RowBox[{"___", ",", 
                 RowBox[{"cathelper", "[", 
                  RowBox[{"a", ",", "a", ",", "_"}], "]"}], ",", "___"}], 
                "]"}]}]}], "]"}]}], ")"}]}], ",", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{"Plus", "@@", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"t", "*", "60", "*", "60"}], "]"}], "&"}], "/@", 
            RowBox[{"SpeciesInRxnsys", "[", 
             RowBox[{"simsys", ",", 
              RowBox[{"thresh", "|", 
               RowBox[{"occ", "[", 
                RowBox[{"___", ",", "thresh", ",", "___"}], "]"}]}]}], 
             "]"}]}], ")"}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]",
         "}"}], "/", "cx"}], "/.", "sol"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.658176974389968*^9, 3.6581769825511*^9}, {
   3.6581770316746273`*^9, 3.658177055451992*^9}, {3.65817710751805*^9, 
   3.658177125021082*^9}, {3.658177172305258*^9, 3.6581772875940123`*^9}, {
   3.658177331358346*^9, 3.658177351396902*^9}, 3.658177391248229*^9, {
   3.6581774592169437`*^9, 3.6581774895542088`*^9}, 3.6581775271460953`*^9, {
   3.658177581339245*^9, 3.658177765009809*^9}, {3.65817804367584*^9, 
   3.6581781870534897`*^9}, {3.658178218229541*^9, 3.6581782234859543`*^9}, {
   3.658178258895137*^9, 3.65817830301057*^9}, {3.658178340948845*^9, 
   3.65817845874533*^9}, {3.65817855691842*^9, 3.6581785579105263`*^9}, {
   3.6581785891753817`*^9, 3.658178625761239*^9}, {3.658178683356732*^9, 
   3.6581786983978157`*^9}, 3.658178791821179*^9, {3.658178941771329*^9, 
   3.658178966202232*^9}, {3.65817935876748*^9, 3.658179410829056*^9}, {
   3.658179518253594*^9, 3.658179528845367*^9}, {3.658179844629434*^9, 
   3.6581798490754766`*^9}, {3.658180464841716*^9, 3.65818046591343*^9}, {
   3.658180559975731*^9, 3.658180560976828*^9}, {3.658183366045186*^9, 
   3.658183389931635*^9}, {3.65818342646646*^9, 3.658183427683107*^9}, {
   3.658183475753326*^9, 3.658183476901313*^9}, {3.658252551275131*^9, 
   3.658252566966916*^9}, {3.6582541992623253`*^9, 3.658254200036768*^9}, {
   3.658265880246676*^9, 3.658265886318184*^9}, {3.65826603726501*^9, 
   3.658266039797709*^9}, {3.6583418207119293`*^9, 3.6583418380015383`*^9}, {
   3.6583448167476473`*^9, 3.658344829069899*^9}, {3.6583450159003057`*^9, 
   3.6583450260429*^9}, 3.6583505841886387`*^9, {3.6584261703612347`*^9, 
   3.658426191878633*^9}, {3.6584263315367393`*^9, 3.658426343710195*^9}, {
   3.658500254146633*^9, 3.658500286922697*^9}, {3.659880580384161*^9, 
   3.659880623362438*^9}, {3.659880746969715*^9, 3.6598807885301523`*^9}, 
   3.66307845696303*^9, {3.711152321206636*^9, 3.711152332240671*^9}, {
   3.711650965360656*^9, 
   3.7116509765657463`*^9}},ExpressionUUID->"1819618b-cfc7-47cc-afa8-\
8e192f8d894f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"dataHelperTrajectories", "[", "s", "]"}], "=", 
     RowBox[{
      RowBox[{"dataRaw", "[", "s", "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.658238425932857*^9, 3.658238483663391*^9}, {
  3.6582387087911043`*^9, 3.658238716503501*^9}, {3.658238767280138*^9, 
  3.658238772871275*^9}, {3.658253628506084*^9, 3.6582536286408377`*^9}, {
  3.66092910888159*^9, 3.660929109998295*^9}, {3.663078457886489*^9, 
  3.663078458811906*^9}},ExpressionUUID->"d03990b6-f92b-4acc-9f9b-\
e8b98186e7bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"dataThresholdTrajectories", "[", "s", "]"}], "=", 
     RowBox[{
      RowBox[{"dataRaw", "[", "s", "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "3"}], "\[RightDoubleBracket]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.658238425932857*^9, 3.658238494579441*^9}, {
   3.6582387176564283`*^9, 3.658238745037848*^9}, 3.6582387789220543`*^9, {
   3.658239006501011*^9, 3.658239006555316*^9}, {3.658253630826989*^9, 
   3.65825363095851*^9}, {3.663078459518812*^9, 
   3.663078460074781*^9}},ExpressionUUID->"e1db8f04-26ba-48ba-84c6-\
33be5d8b3018"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"dataHelperDerivatives", "[", "s", "]"}], "=", 
     RowBox[{"DerivativeFilter", "[", 
      RowBox[{
       RowBox[{"MovingAverage", "[", 
        RowBox[{
         RowBox[{"dataHelperTrajectories", "[", "s", "]"}], ",", "30"}], 
        "]"}], ",", 
       RowBox[{"{", "1", "}"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.660929116906497*^9, 3.660929134320161*^9}, {
  3.660929279703454*^9, 3.660929293807214*^9}, {3.6609296018358603`*^9, 
  3.660929618997066*^9}, {3.660929667000196*^9, 3.660929667058811*^9}, {
  3.663078460828907*^9, 
  3.66307846178621*^9}},ExpressionUUID->"8a237cf5-ac59-4657-ba61-\
e65aed26991d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "Define", " ", "the", " ", "loss", " ", "function", " ", "to", " ", "be", 
    " ", "used", " ", "with", " ", "the", " ", "fitting", " ", 
    RowBox[{"routine", ".", " ", "\[IndentingNewLine]", 
     RowBox[{"NOTE", ":", " ", 
      RowBox[{
      "As", " ", "in", " ", "the", " ", "full", " ", "oscillator"}]}]}]}], 
   ",", " ", 
   RowBox[{
    RowBox[{
    "the", " ", "goodness", " ", "of", " ", "fit", " ", "is", " ", "the", " ",
      "mean"}], "-", 
    RowBox[{
    "squared", " ", "error", " ", "of", " ", "the", " ", "Helper", " ", 
     "derivatives", " ", "data", " ", "vs", " ", 
     RowBox[{"model", "."}]}]}]}], " ", "\[IndentingNewLine]", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.709409290012189*^9, 
  3.7094093132200317`*^9}},ExpressionUUID->"c1e8bd77-a1a1-4e1c-9fae-\
884ef365b634"],

Cell[BoxData[
 RowBox[{
  RowBox[{"meanSquaredError", "[", 
   RowBox[{"datas_", ",", "models_"}], "]"}], ":=", 
  RowBox[{"Mean", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Flatten", "[", "datas", "]"}], "-", 
      RowBox[{"Flatten", "[", "models", "]"}]}], ")"}], "^", "2"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6576505088763638`*^9, 3.657650544789813*^9}, {
  3.657736870813333*^9, 3.657736877449336*^9}, {3.6577379497956257`*^9, 
  3.657737953920827*^9}, {3.657740556483589*^9, 3.6577405679412203`*^9}, {
  3.65835168925985*^9, 3.658351710312516*^9}, {3.659880835455743*^9, 
  3.6598808383507423`*^9}},ExpressionUUID->"257cf667-a1ad-4182-ab5c-\
71f0d799c9d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"myFit", "[", 
   RowBox[{
   "thresh1_", ",", "thresh2_", ",", "thresh3_", ",", "trunctailsfrac_", ",", 
    "leakfrac_", ",", " ", "logkr_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"modelTrajectories", "[", "s", "]"}], "=", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Evaluate", "[", 
          RowBox[{"parameterizedTrajectories", "[", 
           RowBox[{"trunctailsfrac", ",", "leakfrac", ",", "logkr", ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"thresh1", ",", "thresh2", ",", "thresh3"}], "}"}], 
             "\[LeftDoubleBracket]", "s", "\[RightDoubleBracket]"}]}], "]"}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{
            RowBox[{"dataRaw", "[", "s", "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"modelHelperTrajectories", "[", "s", "]"}], "=", 
       RowBox[{
        RowBox[{"modelTrajectories", "[", "s", "]"}], "\[LeftDoubleBracket]", 
        
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"modelThresholdTrajectories", "[", "s", "]"}], "=", 
       RowBox[{
        RowBox[{"modelTrajectories", "[", "s", "]"}], "\[LeftDoubleBracket]", 
        
        RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"modelHelperDerivatives", "[", "s", "]"}], "=", 
       RowBox[{"DerivativeFilter", "[", 
        RowBox[{
         RowBox[{"MovingAverage", "[", 
          RowBox[{
           RowBox[{"modelHelperTrajectories", "[", "s", "]"}], ",", "30"}], 
          "]"}], ",", 
         RowBox[{"{", "1", "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Total", "[", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"meanSquaredError", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"modelHelperDerivatives", "[", "s", "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"dataHelperDerivatives", "[", "s", "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.658240597564851*^9, 3.658240623227475*^9}, {
   3.6582406637473288`*^9, 3.6582406712497177`*^9}, {3.658240707884026*^9, 
   3.658240806591666*^9}, {3.658248913095729*^9, 3.658248921528531*^9}, {
   3.658252245492976*^9, 3.65825225382373*^9}, {3.658252291095682*^9, 
   3.658252398467329*^9}, {3.658253354637928*^9, 3.6582533686174927`*^9}, {
   3.6582536045136127`*^9, 3.6582536072132607`*^9}, {3.65825394410511*^9, 
   3.658254007314041*^9}, {3.658254081669087*^9, 3.658254083921205*^9}, {
   3.6582541423450317`*^9, 3.658254144360718*^9}, {3.658254921382457*^9, 
   3.658254922692162*^9}, {3.658351734662887*^9, 3.658351768883732*^9}, {
   3.658426215167824*^9, 3.658426253333569*^9}, {3.658426322619553*^9, 
   3.658426323922228*^9}, {3.660928832501239*^9, 3.660928832714126*^9}, {
   3.660928893482121*^9, 3.660928982246146*^9}, 3.660929095081395*^9, {
   3.6609297402999783`*^9, 3.660929748995205*^9}, {3.6630237010239277`*^9, 
   3.663023705806951*^9}, {3.663078464014085*^9, 
   3.663078471762804*^9}},ExpressionUUID->"8b36b6f3-544e-4d41-9422-\
a0c36f0eba06"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Note", ":", " ", 
   RowBox[{
   "All", " ", "parameters", " ", "other", " ", "than", " ", "threshold", " ",
     "concentrations", " ", "are", " ", "from", " ", "the", " ", "full", " ", 
    "oscillator", " ", 
    RowBox[{"fit", "."}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{3.709409211452408*^9, 
  3.709409783197833*^9},ExpressionUUID->"6426c8e6-032a-4069-bf99-\
86a569cda570"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "These", " ", "are", " ", "the", " ", "best", " ", "fit", " ", 
    "parameters", " ", "obtained", " ", "with", " ", "fitting", " ", "code", 
    " ", 
    RowBox[{"below", "."}]}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Three", " ", "different", " ", "initial", " ", "concentrations", " ", 
    "of", " ", "Threshold"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"thresh1Fit", ",", "thresh2Fit", ",", "thresh3Fit"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{
     "8.451943686524567`", ",", "9.537184739491499`", ",", 
      "10.601243853333782`"}], "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.6583430809457703`*^9, 3.65834308925909*^9}, {
   3.658346088840049*^9, 3.6583460921071587`*^9}, {3.658351783811358*^9, 
   3.658351789067316*^9}, {3.658426392275195*^9, 3.6584264506862507`*^9}, {
   3.658495764148683*^9, 3.6584957817309237`*^9}, {3.6584967531383533`*^9, 
   3.658496783225355*^9}, {3.659901355105157*^9, 3.659901362390367*^9}, {
   3.660329931826785*^9, 3.6603299418226957`*^9}, {3.660330085210883*^9, 
   3.6603301118934383`*^9}, {3.6630781863424883`*^9, 
   3.6630781895509233`*^9}, {3.66307907780118*^9, 3.663079080937978*^9}, {
   3.6630805406690817`*^9, 3.663080542654751*^9}, {3.709409397813528*^9, 
   3.709409400983098*^9}, {3.709409792149235*^9, 3.709409807597066*^9}, 
   3.711152475709722*^9, {3.711153579900436*^9, 3.711153580845353*^9}, {
   3.7111536391324778`*^9, 3.7111536436671543`*^9}, {3.7111910086760693`*^9, 
   3.7111910147033167`*^9}, {3.711191446907052*^9, 3.7111914481750298`*^9}, 
   3.7111927685111923`*^9, {3.71119408474008*^9, 3.711194103475458*^9}, {
   3.7111941635674686`*^9, 3.71119418932019*^9}, {3.7111944867652063`*^9, 
   3.711194487260957*^9}, {3.7112410596689577`*^9, 3.711241068819873*^9}, 
   3.7116513528492393`*^9},ExpressionUUID->"20a68d1a-125e-4b5e-92aa-\
800b30b95723"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Perform", " ", 
   RowBox[{"fit", 
    StyleBox[
     StyleBox[".",
      FontFamily->"Source Code Pro",
      FontSize->13,
      FontWeight->"SemiBold"],
     FontFamily->"Source Code Pro",
     FontSize->13,
     FontWeight->"SemiBold"], " ", "\[IndentingNewLine]", 
    RowBox[{
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox[
         StyleBox["N",
          FontFamily->"Source Code Pro",
          FontSize->13,
          FontWeight->"SemiBold"],
         FontFamily->"Source Code Pro",
         FontSize->13,
         FontWeight->"SemiBold"],
        FontFamily->"Source Code Pro",
        FontSize->13,
        FontWeight->"SemiBold"], "OT", 
       StyleBox[
        StyleBox[
         StyleBox[
          StyleBox[
           StyleBox["E",
            FontFamily->"Source Code Pro",
            FontSize->13,
            FontWeight->"SemiBold"],
           FontFamily->"Source Code Pro",
           FontSize->13,
           FontWeight->"SemiBold"],
          FontFamily->"Source Code Pro",
          FontSize->13,
          FontWeight->"SemiBold"],
         FontFamily->"Source Code Pro",
         FontSize->13,
         FontWeight->"SemiBold"],
        FontFamily->"Source Code Pro",
        FontSize->13,
        FontWeight->"SemiBold"]}]], 
     StyleBox[
      StyleBox[
       StyleBox[
        StyleBox[
         StyleBox[":",
          FontFamily->"Source Code Pro",
          FontSize->13,
          FontWeight->"SemiBold"],
         FontFamily->"Source Code Pro",
         FontSize->13,
         FontWeight->"SemiBold"],
        FontFamily->"Source Code Pro",
        FontSize->13,
        FontWeight->"SemiBold"],
       FontFamily->"Source Code Pro",
       FontSize->13,
       FontWeight->"SemiBold"],
      FontFamily->"Source Code Pro",
      FontSize->13,
      FontWeight->"SemiBold"], 
     StyleBox[
      StyleBox[
       StyleBox[
        StyleBox[
         StyleBox[" ",
          FontFamily->"Source Code Pro",
          FontSize->13,
          FontWeight->"SemiBold"],
         FontFamily->"Source Code Pro",
         FontSize->13,
         FontWeight->"SemiBold"],
        FontFamily->"Source Code Pro",
        FontSize->13,
        FontWeight->"SemiBold"],
       FontFamily->"Source Code Pro",
       FontSize->13,
       FontWeight->"SemiBold"],
      FontFamily->"Source Code Pro",
      FontSize->13,
      FontWeight->"SemiBold"], 
     RowBox[{
      StyleBox[
       RowBox[{"Comment", 
        StyleBox[
         StyleBox["e",
          FontFamily->"Source Code Pro",
          FontSize->13,
          FontWeight->"SemiBold"],
         FontFamily->"Source Code Pro",
         FontSize->13,
         FontWeight->"SemiBold"], 
        StyleBox[
         StyleBox[
          StyleBox["d",
           FontFamily->"Source Code Pro",
           FontSize->13,
           FontWeight->"SemiBold"],
          FontFamily->"Source Code Pro",
          FontSize->13,
          FontWeight->"SemiBold"],
         FontFamily->"Source Code Pro",
         FontSize->13,
         FontWeight->"SemiBold"]}]], 
      StyleBox[" ",
       FontFamily->"Source Code Pro",
       FontSize->13,
       FontWeight->"SemiBold"], "out", " ", "to", " ", "use", " ", 
      "previously", " ", "obtained", " ", "best", " ", "fit", " ", 
      "parameters", " ", 
      RowBox[{
       RowBox[{"(", "above", ")"}], "."}]}]}]}]}], "\[IndentingNewLine]", 
  "*)"}]], "Input",ExpressionUUID->"97e56326-d838-4307-b6f6-79c848023238"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"iter", "=", "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{"bestfit", "=", 
     RowBox[{"FindMinimum", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Hold", "[", 
        RowBox[{"error", "=", 
         RowBox[{"myFit", "[", 
          RowBox[{
          "thresh1", ",", "thresh2", ",", "thresh3", ",", " ", 
           "trunctailsfracFit", ",", "leakfracFit", ",", " ", "logkrFit"}], 
          "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"thresh1", ",", "thresh1Fit"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"thresh2", ",", "thresh2Fit"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"thresh3", ",", "thresh3Fit"}], "}"}]}], "}"}], ",", 
       RowBox[{"MaxIterations", "\[Rule]", "10000"}], ",", 
       RowBox[{"Method", "\[Rule]", "\"\<PrincipalAxis\>\""}], ",", 
       RowBox[{"EvaluationMonitor", "\[RuleDelayed]", "\[IndentingNewLine]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"iter", "++"}], ";", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"thresh1Fit", ",", "thresh2Fit", ",", "thresh3Fit"}], 
            "}"}], "=", 
           RowBox[{"{", 
            RowBox[{"thresh1", ",", "thresh2", ",", "thresh3"}], "}"}]}]}], 
         ")"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "*)"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.658254274627078*^9, 3.6582544477692833`*^9}, {
   3.658425995504751*^9, 3.6584260955549107`*^9}, 3.6584265782696753`*^9, {
   3.658496881649725*^9, 3.658496884187489*^9}, {3.659902042049184*^9, 
   3.659902079869652*^9}, 3.660930133672194*^9, {3.709409441610239*^9, 
   3.7094094474587803`*^9}, {3.711153222641683*^9, 3.711153228867343*^9}, {
   3.711192772046741*^9, 3.711192774833427*^9}, {3.711237510059725*^9, 
   3.7112375118873377`*^9}, {3.711649786733777*^9, 3.711649789993376*^9}, {
   3.7116509973925533`*^9, 3.711651000468438*^9}, {3.711651357868123*^9, 
   3.711651360669009*^9}},ExpressionUUID->"40f44ed4-2246-4a09-8d01-\
5038afe2aa06"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.0034296101493466536`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"thresh1", "\[Rule]", "8.451943686524567`"}], ",", 
     RowBox[{"thresh2", "\[Rule]", "9.537184739360788`"}], ",", 
     RowBox[{"thresh3", "\[Rule]", "10.601243853333782`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.711651035764147*^9, 
  3.711651196629222*^9},ExpressionUUID->"2c744f97-d554-4afb-944a-\
54ff483a483c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Dynamic", "[", "iter", "]"}], ",", 
   RowBox[{"Dynamic", "[", "error", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.658254455351412*^9, 
  3.658254469116538*^9}},ExpressionUUID->"5ae48608-3693-4fb6-9be1-\
e7ea899829a7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   DynamicBox[ToBoxes[$CellContext`iter, StandardForm],
    ImageSizeCache->{23., {0., 9.}}], ",", 
   DynamicBox[ToBoxes[$CellContext`error, StandardForm],
    ImageSizeCache->{78., {1., 9.}}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.658254496565596*^9, 3.658351416926134*^9, 3.658352507169354*^9, 
   3.658496353504294*^9, 3.659209526347484*^9, 3.659211405989277*^9, 
   3.659902035310419*^9, 3.6609298912327757`*^9, 3.6624924313827057`*^9, 
   3.662492683363385*^9, 3.66302258582802*^9, 3.6630785361360292`*^9, 
   3.663080748859747*^9, 3.663092554254023*^9, 3.711153246899179*^9, 
   3.711191567585948*^9, 3.711192779533204*^9, 3.7111940463597116`*^9, {
   3.7111940869761333`*^9, 3.711194104794716*^9}, {3.711194166661305*^9, 
   3.7111941903448687`*^9}, 3.71119448898365*^9, 3.711237148433857*^9, 
   3.7112374160179234`*^9, 3.711237496816122*^9, 3.711241038529265*^9, 
   3.7116497925348883`*^9, 3.7116510457478933`*^9, 
   3.7116511966865597`*^9},ExpressionUUID->"163b0873-bf4b-4b97-9f36-\
bc31d8bf9d66"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dynamic", "[", 
  RowBox[{"{", 
   RowBox[{"thresh1Fit", ",", "thresh2Fit", ",", "thresh3Fit"}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.65825451897971*^9, 3.6582545288280582`*^9}, {
  3.658426542064073*^9, 3.658426566168243*^9}, {3.711153681467594*^9, 
  3.7111536821319923`*^9}},ExpressionUUID->"892e20b0-aed2-4dfd-a7da-\
8703226c67ca"],

Cell[BoxData[
 DynamicBox[
  ToBoxes[{$CellContext`thresh1Fit, $CellContext`thresh2Fit, \
$CellContext`thresh3Fit}, StandardForm],
  ImageSizeCache->{207., {3., 9.}}]], "Output",
 CellChangeTimes->{
  3.658254546965562*^9, 3.6583514169882174`*^9, 3.658352507212063*^9, {
   3.6584265455764427`*^9, 3.658426566942746*^9}, 3.6584270815238447`*^9, 
   3.6584963879219913`*^9, 3.659209526404625*^9, 3.659211406023147*^9, 
   3.659902036827661*^9, 3.66092989125287*^9, 3.6624924314175367`*^9, 
   3.662492683407607*^9, 3.6630225860300083`*^9, 3.663078536184897*^9, 
   3.6630807488938847`*^9, 3.663092554291041*^9, 3.711153246973743*^9, 
   3.711153682677618*^9, 3.711191567634139*^9, 3.711192779583506*^9, 
   3.711194046398471*^9, {3.71119408701044*^9, 3.711194104834861*^9}, {
   3.711194166703032*^9, 3.711194190396215*^9}, 3.711194489039667*^9, 
   3.711237148487735*^9, 3.7112374160724573`*^9, 3.71123749686863*^9, 
   3.711241040666696*^9, 3.711649792560274*^9, 3.711651045806388*^9, 
   3.711651196715335*^9},ExpressionUUID->"5ed27675-9303-47b8-9191-\
b2d751bb0790"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"thresh1Fit", ",", "thresh2Fit", ",", "thresh3Fit"}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.71115368602639*^9, 
  3.711153686516387*^9}},ExpressionUUID->"497c027b-74d8-44ee-a4ee-\
bf12f8ef784d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8.451943686524567`", ",", "9.537184739491499`", ",", 
   "10.601243853333782`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.659211406905308*^9, 3.6599021754648314`*^9, 3.660929891284148*^9, 
   3.662492431450029*^9, 3.662492683456815*^9, {3.66249297892511*^9, 
   3.662493003506364*^9}, 3.6624930354540052`*^9, 3.6624931251470118`*^9, 
   3.662493309940432*^9, 3.663078536234221*^9, 3.663080748926996*^9, 
   3.663092554322071*^9, 3.711153247025015*^9, {3.7111536872640343`*^9, 
   3.711153697873555*^9}, 3.711191567668742*^9, 3.711192779632349*^9, 
   3.711194046448498*^9, {3.711194087064334*^9, 3.711194104885034*^9}, {
   3.7111941667542143`*^9, 3.711194190447032*^9}, 3.71119448908967*^9, 
   3.711237148538842*^9, 3.7112374161228523`*^9, 3.71123749691642*^9, 
   3.711241042904512*^9, 3.71164979260343*^9, 3.711651045848852*^9, 
   3.7116511967437983`*^9},ExpressionUUID->"2969fa11-3ac2-4043-8093-\
c623657dd280"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compare model and data", "Subsection",
 CellChangeTimes->{{3.658176429855425*^9, 3.65817644173873*^9}, {
  3.6581796541136227`*^9, 
  3.658179657951417*^9}},ExpressionUUID->"bcbd7000-2c08-460a-848e-\
5acc1a8b4285"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"modelTrajectories", "[", "s", "]"}], "=", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{"parameterizedTrajectories", "[", 
         RowBox[{
         "trunctailsfracFit", ",", "leakfracFit", ",", "logkrFit", ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"thresh1Fit", ",", "thresh2Fit", ",", "thresh3Fit"}], 
            "}"}], "\[LeftDoubleBracket]", "s", "\[RightDoubleBracket]"}]}], 
         "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", 
         RowBox[{
          RowBox[{"dataRaw", "[", "s", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "1"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.6581800993868217`*^9, 3.658180144953817*^9}, {
   3.658180183595237*^9, 3.658180199323659*^9}, {3.6581802312957983`*^9, 
   3.658180270479205*^9}, {3.658180369318593*^9, 3.658180412265308*^9}, {
   3.65818045022034*^9, 3.658180453064979*^9}, {3.658180843201289*^9, 
   3.658180948640965*^9}, {3.658180986506586*^9, 3.6581810084640408`*^9}, 
   3.6581817790417337`*^9, {3.6581838154170027`*^9, 3.658183818283224*^9}, {
   3.6581838887498417`*^9, 3.658183897280558*^9}, {3.658183955400037*^9, 
   3.6581839886156397`*^9}, {3.658184042021879*^9, 3.658184081503585*^9}, {
   3.658184122756682*^9, 3.658184126152515*^9}, {3.658238288494475*^9, 
   3.658238340551744*^9}, 3.658254725821933*^9, {3.658426700566194*^9, 
   3.6584267118819113`*^9}, {3.658427031637767*^9, 3.658427033091978*^9}, {
   3.65842714379068*^9, 3.658427155609674*^9}, {3.663078472816208*^9, 
   3.663078474364045*^9}},ExpressionUUID->"050b9f30-14f4-435c-968a-\
2171c24b0891"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"modelHelperTrajectories", "[", "s", "]"}], "=", 
     RowBox[{
      RowBox[{"modelTrajectories", "[", "s", "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.658238425932857*^9, 3.658238483663391*^9}, {
  3.65823872242914*^9, 3.658238724020939*^9}, {3.658253641623561*^9, 
  3.658253641762138*^9}, {3.6630784750238037`*^9, 
  3.663078475505135*^9}},ExpressionUUID->"6f1b451e-30da-4290-8fbc-\
8137bd3d731f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"modelThresholdTrajectories", "[", "s", "]"}], "=", 
     RowBox[{
      RowBox[{"modelTrajectories", "[", "s", "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.658238425932857*^9, 3.658238494579441*^9}, 
   3.6582387268217993`*^9, {3.6582536438848143`*^9, 3.658253644047689*^9}, {
   3.663078476108438*^9, 
   3.6630784766308603`*^9}},ExpressionUUID->"c9c14027-5c60-4a11-bca7-\
e28ffc563a9a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"modelHelperDerivatives", "[", "s", "]"}], "=", 
     RowBox[{"DerivativeFilter", "[", 
      RowBox[{
       RowBox[{"MovingAverage", "[", 
        RowBox[{
         RowBox[{"modelHelperTrajectories", "[", "s", "]"}], ",", "30"}], 
        "]"}], ",", 
       RowBox[{"{", "1", "}"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], ";"}]], "Input",Expres\
sionUUID->"d80e514d-9434-4714-996a-eaed5d502c60"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotModelHelper", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"modelHelperTrajectories", "[", "s", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", "\n", 
     
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Datapoint\>\"", ",", "\"\<Conc(nM)\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "->", 
      RowBox[{"Directive", "[", 
       RowBox[{"FontFamily", "->", "\"\<Helvetica\>\""}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
     "PlotLabel", " ", "\[Rule]", " ", "\"\<Autocatalyst  Helper\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Red", ",", " ", "Thick"}], "}"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "100"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "->", 
      RowBox[{"1", "/", "1.3"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6581313761021833`*^9, 3.658131380888214*^9}, {
   3.658131452620285*^9, 3.658131524286695*^9}, {3.658131668562601*^9, 
   3.6581316784718733`*^9}, {3.6581317116404333`*^9, 3.658131712148192*^9}, {
   3.658177556471148*^9, 3.658177561065317*^9}, {3.6581836677783127`*^9, 
   3.6581836804721127`*^9}, {3.6581837450739107`*^9, 3.658183780642686*^9}, 
   3.658184184606538*^9, {3.6582383930133247`*^9, 3.658238395266575*^9}, {
   3.658238512528413*^9, 3.658238570079186*^9}, {3.658238608098534*^9, 
   3.658238648752429*^9}, 3.6582387302988253`*^9, {3.658238828026306*^9, 
   3.6582388477685013`*^9}, {3.658238921271546*^9, 3.658238922658916*^9}, {
   3.658265173159377*^9, 3.6582651933846617`*^9}, {3.658265741982126*^9, 
   3.658265752438101*^9}, {3.663078477482546*^9, 
   3.663078480988756*^9}},ExpressionUUID->"9d7c3b30-ed4a-48c6-b83b-\
a331e36decfc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotModelThreshold", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"modelThresholdTrajectories", "[", "s", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", "\n", 
     
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Datapoint\>\"", ",", "\"\<Conc(nM)\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "->", 
      RowBox[{"Directive", "[", 
       RowBox[{"FontFamily", "->", "\"\<Helvetica\>\""}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
     "PlotLabel", " ", "\[Rule]", " ", "\"\<Autocatalyst  Threshold\>\""}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Red", ",", " ", "Thick"}], "}"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "5"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "->", 
      RowBox[{"1", "/", "1.3"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6581313761021833`*^9, 3.658131380888214*^9}, {
   3.658131452620285*^9, 3.658131524286695*^9}, {3.658131668562601*^9, 
   3.6581316784718733`*^9}, {3.6581317116404333`*^9, 3.658131712148192*^9}, {
   3.658177556471148*^9, 3.658177561065317*^9}, {3.6581836677783127`*^9, 
   3.6581836804721127`*^9}, {3.6581837450739107`*^9, 3.658183780642686*^9}, 
   3.658184184606538*^9, {3.6582383930133247`*^9, 3.658238395266575*^9}, {
   3.658238512528413*^9, 3.658238570079186*^9}, {3.658238608098534*^9, 
   3.658238648752429*^9}, 3.6582387302988253`*^9, {3.658238828026306*^9, 
   3.6582388658541183`*^9}, {3.658238924962659*^9, 3.658238932070822*^9}, {
   3.658265772255652*^9, 3.658265778072082*^9}, {3.663078482604748*^9, 
   3.663078484236986*^9}},ExpressionUUID->"ad35ca82-1d27-4f87-912d-\
b953efbb2f4b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotModelHelperDerivatives", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"modelHelperDerivatives", "[", "s", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", "\n", 
     
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Datapoint\>\"", ",", "\"\<dnM/datapoint\>\""}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "->", 
      RowBox[{"Directive", "[", 
       RowBox[{"FontFamily", "->", "\"\<Helvetica\>\""}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
     "PlotLabel", " ", "\[Rule]", " ", 
      "\"\<Autocatalyst  Helper Derivatives\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Red", ",", " ", "Thick"}], "}"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "->", 
      RowBox[{"1", "/", "1.3"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6581313761021833`*^9, 3.658131380888214*^9}, {
   3.658131452620285*^9, 3.658131524286695*^9}, {3.658131668562601*^9, 
   3.6581316784718733`*^9}, {3.6581317116404333`*^9, 3.658131712148192*^9}, {
   3.658177556471148*^9, 3.658177561065317*^9}, {3.6581836677783127`*^9, 
   3.6581836804721127`*^9}, {3.6581837450739107`*^9, 3.658183780642686*^9}, 
   3.658184184606538*^9, {3.6582383930133247`*^9, 3.658238395266575*^9}, {
   3.658238512528413*^9, 3.658238570079186*^9}, {3.658238608098534*^9, 
   3.658238648752429*^9}, 3.6582387302988253`*^9, {3.658238828026306*^9, 
   3.6582388477685013`*^9}, {3.658238921271546*^9, 3.6582389577832947`*^9}, {
   3.6582657696513987`*^9, 3.658265769867611*^9}, {3.660930001822407*^9, 
   3.6609301033855143`*^9}, {3.6630784850252523`*^9, 
   3.6630784873729277`*^9}},ExpressionUUID->"c9cab3d3-f667-46ef-b359-\
f2c859bf3133"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotDataHelper", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"dataHelperTrajectories", "[", "s", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", "\n", 
     
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Datapoint\>\"", ",", "\"\<Conc(nM)\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "->", 
      RowBox[{"Directive", "[", 
       RowBox[{"FontFamily", "->", "\"\<Helvetica\>\""}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
     "PlotLabel", " ", "\[Rule]", " ", "\"\<Autocatalyst  Helper\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Red", ",", " ", "Thick"}], "}"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "100"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "->", 
      RowBox[{"1", "/", "1.3"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6581313761021833`*^9, 3.658131380888214*^9}, {
   3.658131452620285*^9, 3.658131524286695*^9}, {3.658131668562601*^9, 
   3.6581316784718733`*^9}, {3.6581317116404333`*^9, 3.658131712148192*^9}, {
   3.658177556471148*^9, 3.658177561065317*^9}, {3.6581836677783127`*^9, 
   3.6581836804721127`*^9}, {3.6581837450739107`*^9, 3.658183780642686*^9}, 
   3.658184184606538*^9, {3.6582383930133247`*^9, 3.658238395266575*^9}, {
   3.658238512528413*^9, 3.658238570079186*^9}, {3.658238608098534*^9, 
   3.658238648752429*^9}, 3.6582387302988253`*^9, {3.658238828026306*^9, 
   3.6582388477685013`*^9}, {3.658238921271546*^9, 3.6582389577832947`*^9}, {
   3.6582657696513987`*^9, 3.658265769867611*^9}, {3.663078488514111*^9, 
   3.663078489921453*^9}},ExpressionUUID->"38d6ed55-1aa7-4fac-a1f7-\
fb267a76d1c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotDataThreshold", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"dataThresholdTrajectories", "[", "s", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", "\n", 
     
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Datapoint\>\"", ",", "\"\<Conc(nM)\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "->", 
      RowBox[{"Directive", "[", 
       RowBox[{"FontFamily", "->", "\"\<Helvetica\>\""}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
     "PlotLabel", " ", "\[Rule]", " ", "\"\<Autocatalyst  Threshold\>\""}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Red", ",", " ", "Thick"}], "}"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "5"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "->", 
      RowBox[{"1", "/", "1.3"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6581313761021833`*^9, 3.658131380888214*^9}, {
   3.658131452620285*^9, 3.658131524286695*^9}, {3.658131668562601*^9, 
   3.6581316784718733`*^9}, {3.6581317116404333`*^9, 3.658131712148192*^9}, {
   3.658177556471148*^9, 3.658177561065317*^9}, {3.6581836677783127`*^9, 
   3.6581836804721127`*^9}, {3.6581837450739107`*^9, 3.658183780642686*^9}, 
   3.658184184606538*^9, {3.6582383930133247`*^9, 3.658238395266575*^9}, {
   3.658238512528413*^9, 3.658238570079186*^9}, {3.658238608098534*^9, 
   3.658238648752429*^9}, 3.6582387302988253`*^9, {3.658238828026306*^9, 
   3.6582388658541183`*^9}, {3.658238924962659*^9, 3.658238932070822*^9}, {
   3.658238966210853*^9, 3.658238970548443*^9}, {3.658265781047776*^9, 
   3.65826578293053*^9}, {3.663078490605204*^9, 
   3.663078492227869*^9}},ExpressionUUID->"8c2706bf-ebce-4673-a4d9-\
3dddfafeb516"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotDataHelperDerivatives", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"dataHelperDerivatives", "[", "s", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", "\n", 
     
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Datapoint\>\"", ",", "\"\<dnM/datapoint\>\""}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "->", 
      RowBox[{"Directive", "[", 
       RowBox[{"FontFamily", "->", "\"\<Helvetica\>\""}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
     "PlotLabel", " ", "\[Rule]", " ", 
      "\"\<Autocatalyst  Helper Derivatives\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Red", ",", " ", "Thick"}], "}"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "->", 
      RowBox[{"1", "/", "1.3"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6581313761021833`*^9, 3.658131380888214*^9}, {
   3.658131452620285*^9, 3.658131524286695*^9}, {3.658131668562601*^9, 
   3.6581316784718733`*^9}, {3.6581317116404333`*^9, 3.658131712148192*^9}, {
   3.658177556471148*^9, 3.658177561065317*^9}, {3.6581836677783127`*^9, 
   3.6581836804721127`*^9}, {3.6581837450739107`*^9, 3.658183780642686*^9}, 
   3.658184184606538*^9, {3.6582383930133247`*^9, 3.658238395266575*^9}, {
   3.658238512528413*^9, 3.658238570079186*^9}, {3.658238608098534*^9, 
   3.658238648752429*^9}, 3.6582387302988253`*^9, {3.658238828026306*^9, 
   3.6582388477685013`*^9}, {3.658238921271546*^9, 3.6582389577832947`*^9}, {
   3.6582657696513987`*^9, 3.658265769867611*^9}, {3.660930001822407*^9, 
   3.6609300733967113`*^9}, {3.663078493043159*^9, 
   3.663078494648307*^9}},ExpressionUUID->"f82f8f41-23c6-4497-b002-\
13386af327da"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "plotModelHelper", ",", "plotModelThreshold", ",", 
   "plotModelHelperDerivatives"}], "}"}]], "Input",
 CellChangeTimes->{{3.658238868438539*^9, 3.6582388872124577`*^9}, {
  3.660930110533146*^9, 3.660930110732086*^9}, {3.663078496016203*^9, 
  3.663078497053536*^9}},ExpressionUUID->"6be72144-6e2b-4657-b4ed-\
54721aae4d95"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {{}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw1knk8lAvYhqeOokWkOkdFoSRlKwkhd1KWFvte2fdtxjozhpk2TgshJ0ep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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw1lXk81Hv7h5U2PXRISVKEU0qb1lNR7yJlF4oQY19jzJiFGWNKyaGkUmkR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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw91nc8Ff7fxvGTBq3vT1N9EzIqJVGkNFzIyOrYMnLszcE5xnE4R0MqFSUN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        "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
    AspectRatio->0.7692307692307692,
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0., 0},
    DisplayFunction->Identity,
    Frame->{{True, True}, {True, True}},
    FrameLabel->{{
       FormBox["\"Conc(nM)\"", TraditionalForm], None}, {
       FormBox["\"Datapoint\"", TraditionalForm], None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    LabelStyle->Directive[FontFamily -> "Helvetica"],
    Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotLabel->FormBox["\"Autocatalyst  Helper\"", TraditionalForm],
    PlotRange->{{0., 519.}, {0, 100}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {0, 0}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw1lXlcjevbxRtpZKM0CEWmSDMpsQwnQ6JRkzQPGnfjbjfsvUMyJOGESsSP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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw1lnlcjOsbxseScyo6SWRLU1GWaCFCcpUKLUcLLdqmfZOmaZ1pm7JlXyJr
DKGyJtnFpA3hVKIQCmWNlCiUX7/Pc+cPPl/Pe73X+33u531L3Sfcwb8/h8P5
q/ev///L/rTOjxxS2SA7TBP0H3C3eMnRGDuY+G/kR6kMkbWWJVZEx5AnpiZa
fxErw+qs1/H+MTLEI5HZdZz7YO0A4rG4rrtooOmDfsRcVJjUDN6TyiHWwPlO
1der/vTMZzwe323dix96dRNrwcnixStNud/EE1EwjKeY//En8WTUfZBuE/zo
ItaBXqhH5ODxfTwNGks7FA6HdBLrwfB3WsDfZT+I9RGa2O5ob9DHBjhjlhEU
euo78XRMlbPrbNHv4xm45L243ydpB7Ehpi/ItX7m3Mczcb1Qai3q+EY8C5rK
Q2SL9vSxEeQWFro9Rh/PRryF1kmZlnbiOYhbnFl46UAfzwXHJ/RN2JI+Nkb/
dxfjCgf28TwY3b7baH29jdgEm92XfamI7uP5ODp3cOkvvT4G1PwfKGa1fGUs
Bmz1FaK2nyTmmMJ/L989M6Rv3RQ3/N9lHZnct26GuIhDMqkfW2ndDG8y/tvM
PU3MWYAVs8acCAjvW18AjQbHhvkGfevmqKoY1jLj4xdaN8efexcK7wuIORYw
bOkZpPvrM61bQNV/2lusJuZY4q1h65XPQ/rWLWGbFPtlwp4WWl8Ik8zuZ481
iMULYfitM7T99CdaXwTz3OVJ4bOJxYuw5kLeOpR+pPXFWFWkYuhhTyxejNKi
tbsLn3+gdSv0H7H17vIQYrEVlOota6b9eE/r1uiXX31ixmpisTUK5TcoBw3t
W7fBbtmVCaUH39G6DVK+eE2z0iHm2KJ+oHlN+5W3tG6Lo79u/ZIuJOb8i9vq
9fy8R820/i/MFwTeLvIl5iyBpsfJ2m9fm2h9CYyNM8dbiYk5dhgxOFBwS4EY
digerGnilfmGrreDwey6KRo6xFI7LLbMDBxy7TXl7aH9vL1I04oY9vi1bf3Q
oCevKG+PgdEn/n4RRCy1x4DztgXrOxsp74CpaaIl4WnE6OWe5XI7RxKLHaBU
7m3RndNAeQesmSV8mjebmOOIkkeP5EN3vaS8I3y/m1iOv/yC8o54PVB068Cz
55R3RPcJJ5OmP/WUXwrNAtuXChOIsRTu3DdyU62fUX4pYtX+/HIUPKX8UpyS
dxq8d98Tyi9DTtrmX8NK6ii/DPkB+V/qP9dSfhlqDVbrKIwhli5DRldVa/Gi
x5R3wuoq2YbRcY8o74T6e8/8DXJrKO+EzO0h9lPqH1LeCW0pmtHaQ4k5zjiU
/93MelE15Z1hc8b4+7WUKso7I8TolObhwkrKO+NZ/pkey87/KO+CA6mfvj0T
PaC8C+a7PfniMuA+5V1wRD9DS2VHBeVdUDtp67wo7buUdwV3XOnyB8W3Ke+K
YEVX07WB5ZR3xT+V7zf8ViqjvCvczwaL08tKKL8cs/Zq5J1KLab8cuRoaSXn
LLxF+eVwe7zle/PwIsovx7cP94PXPrtJeTcEeHbF6B4qpLwbjo1/+Hd47DXK
uyF9ZtPJN35XKO8GY6eejWpBlyjvjpEh/X8eTLlAeXfY5Ra8fHjuPOXdceNu
3OphXeco747aeTvcsp3zKO+B+9e+vgvcf5ryHuh+HXhIcvEE5T3QdHJU8lNO
DuU9ENumPL9CeIzynsCTnEEfuVmU98TeYQ9twzoklPfELoNDdTc/ZVLeEz4u
opSv5vso74WzcaXRF1szKO+Fa8XLXbI/pVPeCwmiAWMMDLdT3gsBm8fFXdy0
mfI8yKoevdIyaz1jLg/GTf3eTPVdQ/fj4fIU5XCeTCpjHg+hJ808Aycn0f15
UBElh+cpCRlLeDj+1e94R14U9fEgH6yzRKWdz7iBh+SXv4LPbwmlfm/4WTdN
kJ8TQP3eyE+VrU4o96Z+b2QbPpRNm+FO/d44+kV72PepTtTvjRHXbUe1LbKn
fm9ozD2nbHjBivq9oWXhn68eYU793uhcOFdY+MeE+n3wo2hS2S+LWdTvg6JB
I9Y/sdKnfh8UX+HGf1sxifp9sFb7+8rwRA3q98GhowYbI/eNpn4fuDa4P937
WYn6fXDnQZlBca4c9ftg3bp3z3s296d+X4h1K8KMN3SZsH5fxL766rjQ5Stj
+OKq5bT/Ppq+ZczzRd3dsNCTxS8Yi30xKkRFOFGphrHEF50DIgNM6+4wlvpC
7eeBZ59FUsYNvmj3iLo6raSAMccPygVKNSkFudTvh0T7elH8gEPU7wetibq3
gix2UL8fXkw2+nfi4jXU74c6eUVnlzNx1O+HhG7u1rKUFdTvhzxdxUS3257U
7wc7pcYc4+dLqN8fQpOh95+bT6d+f8SMi24eUFBbyPr9cc9057uRljo3WL8/
hvjGmdes1WMs9sejjV6lM9KmMpb445NQbXa1wyTGUn+MGKoyTuuPFuMGf8i0
9WQc3q7BmBOAc62YeHv3CMbcAFi1HRp+drccYwSgYpDe3ehzbex5eAGo+iof
9Eb5MmNxAPRnJ9e5ij4ylgQg+OQo+7Xt5+ex/gAM1/514eWiNsYNAeA3dujW
cul+nEC8nsSbk1DwgzE3ENETTn1RbOpH+x+InT4z/jJ0OMzyvEDUBNrqNfxW
Iv9AHJu3Lr/LTZ72PxAtk9XNQn1G0f4HQnN4tPjQ/ink33u9aJXskfuq5B+E
X08ebrWZ9476g7Bo3+oxod2G5B+EvOnHlpVOMaD5B0FZdemqvxeNpP4gbL2t
dqfAXJ/2PwgjGs8v7ZczjfqDsD6444FqjhLNPwjZMes/ON/8wXw4wTgerjNu
p1kDY24wbA23PrfYWc4YwXhqn3hY5bWA/IMRua1Oh59ZTPsfjAJNS5+NohLa
/2Ds81xc/z61jLE0GK5KJ1NU3QoZNwTDbvXB3xnGB2j/Q3D30uh6yYtt1N/L
K11KZfJOUH8IHqiurxydson6Q1AgXHxTlETPI+693n5NSWZbCvWHIP6VUkbm
z53UHwJJ6UDfpLwE6g9BhftDPwXHNOoPxYbjgT1h6qtp/0OxS9vvobW9H/WH
QrLlleb+4lTqD8UZyePapOZ46g9FzGfVaY0THRlLQlHoc11Yr0vPJw3FWOd3
aXb9ouj8haLdYs7I/e/CqH8F5Ix+a3Eviah/BVSn28mVOFMeK7DdtqLZVzud
+lfAf331R/flMdS/Am/+PFm457iE/Hvvt77h69ag3eS/AiqmRh/tXU9R/wp0
n9v4aKHHJZp/GBZ8XTpo/4lc6g/DJrPZMw5dqqT3Pww3nVP02vvR/Hi96z0Z
jys20/slDkNH1/Vkzxc0b0kYZKKsxl1rlFJ/GKzinyreHVNF/WEoHL74RGFB
HvWvxNOh6WlP/tRQ/0p8P9NUNTfsDvmvRP3RA352W+l88lZiWUtG7rmb9Pzi
lRgrNhvrVXiS9n8lQl59688ZG0T7vxJfiu00Y4+60fxXIn9y/KUZ1VbUHw6X
jyOdSjb50vkLh6dL+aSoU07UHw6lKTuHBz4wov5wfDs24tSHl1+MWX84UlVa
7bV2vGcsCYdmUMvGDK9GxtJwpOxQNXyfEcW4IRyDnSM2qS2tus76+dA6WD1k
oGERY0U+kmvvm+evimPXc/kYMOlgdMCHTMZ6fIyfb5eTyt/ErgcfCSNVRIPs
Mhnb8bFPSe5g873zjHl8aCic/3x9bBZjPh9TvyhbTog4zFjMx01hrXxBygJ2
/218lJ8+zDk4ZjX58DHp9Pgwoyk8xnl87NbYrFjmJCY/PuzXrEt3GeXK7lfJ
R5xpc9n+ISmMG/jYrp4+5ufnjYxb+TiwU+f2n5j15B8Bx7WBG8x1VpF/BJRn
ZenWfxcz5kbgl6n7nvBWf8Z6EbDUH2+nPzmC9SMCSupTOoz7xzK2i0DLiMeq
6pfNyT8CFbKDDhtlOLF1fgRyBWa+j29upflFoGycdlJHG/G2CJwQTeC/37yF
5SURiHjHU+6q82OcF4FErvjTWzVbxtIIpHWMVizo0CT/CAzcvnpCSnA/mncE
rGccnt51tm0u84/A6BHOMZact9eYvwDDN55ZEzahka0rClCxt19nwf7+NH8B
Phlu9HiyvJOt6wlwvDhNfLxek/wFyDg/IXHRbBXyFyDK5IYeN5T6eQL8fu9s
qjd1BPkLsF7bH+PcvrH7iQUoiLD6kKdQx3ibAEqqn+WLkmoZSwQwcXjdf+ay
N+x583rX09IHWIe9ZCwVwHPX5Xm3X2YzrhQg9WBa3k2zApZvEEB2xgfFsc8y
yV8AudE1vF3uVYw5kdD4tPBCjvUb8o/E1RklCRo6zxlzI/Fy3mP93ReK2f31
IhHYmJvjmHKfMSLhMDpkbN7yAsZ2kZDaXQ0ZHb6HMS8Slzh/AksdbjDmR2Lj
TYOtfx0oZyyOxK1flibZwecYb4vEjTs7xieNDyT/SMipnm3+3bmK/CMx91TF
I/Xvx8k/Ekon0z86jd9O/pE4o3LxwpXOc+QfCb0ii9e2dqXkH4lvj0Z+3d56
j/yj0F7zxNQ34D/yj4L5GJ8zKoEV5B+FFfIbFsGzkOYfhWyHlN+ptgfIPwqW
Qz5Y/UzMI/8oVKZ6KXPqVrHreVE4q1nyeOTucsb8KExrONWlWlFD849CZ5kH
p1JC/dui8CN3TbOsVjq7nyQK1SdLFCxqn5F/FPLvd/WXCOk8SKPw/ufqR+9F
9eQfha494wZNDb9O/r3r77eNU0hpIf8oaF+LcHadR+ePE43XD5XidjZ9If9o
hG28arW0lZ6PG43krFqLgTXkqxcNr4/X5xTfriT/aOhsi6kyXPqK/KMxYEhR
e4t/E80/GjURP6Q2yo9o/tG4LJLrVrMW0fyjMf/0P/a5q5LIPxqJ4Vm6ns2R
5B+N1ELu6O4XW8m/9/opS7L3qQnJPxrV5XP+silVI/9o2ISm9+x460j+0dgs
Gpz03HcS+UfjloPe4Q4ZXXr/Y7D7sYHS+tUa5B8DwfzMeENLI/Lv5VqjoFj9
8TT/GASNXvFOcdIyxojBzYXdk89d92NsF4OPFjbaj31n0Pxj0NIxIPOQOeX5
MfiQ+uLwrM82NP8YrBxSreDS+ukq849BcH58qfkdA/KPwS8DxShHCwXyj8Gr
tQ6Nq1oHsrw0BmerTANazg0n/xiYTb6h7qryF+OGGGz441uYs1eR/GPQ+m9K
vnCXCs0/Fpt4R1a92NHJ+hVjcTbC2zR980vG3FgETXGTCg0mkH8sdB+tUU26
PIv8Y3Gn8/bjQQvnkH8sdJ6nTnjxaSr5x0I/fIjmjmx1mn8sjkztMHS/bUjz
j8X55813rb9NoPc/FnPV/XS7m2j/JLFYkPDRuEprAeO8WBjndHW4WOmTfyw2
/316V5OWKfnH4oVNWPmsZgfyj0V26c3t+7cSt8ZCTWRebTjKkuYfh1GuyrvL
S/r841D4WT99bgr1c+MgM10rMmuhIfnHIUvb5/lJrib5x2FD65Ax64UcOv9x
OO1j/6rMSIbOfxxGtGRKhY4f5zD/OHyIWnUjzfo9Y3Hv/RvVjy74dyD5x2HL
OpOCpa5KNP84GGtuiTzt2jf/OKS27gp8Lv8fy0vjUBJWcfVIVhfjyjh4lH07
MFSN7t8QB3HIoMu6rjXMrzUOmXdRvrO7mjFHCJv6RzkeHvXsekUh9JbcO3bX
q50xV4hinsY+23EdjPWE8DHziHQc+JUxhOA5DZ6Vda2bsZ0QFRYx6zakytD8
hXj/Q+PEP4kD6PwLYVnr/SdtXhv5C3FohMfFI2d+MN4mhN9SjqvnADrfEiEO
bFRNc036i+YvxLdMxbr3Pzg0fyEu9CSV7anvIf/e++fdPZV5jdYbhKiubukc
V/GHrbcKUfVuau6Th9TPEeFTxc/4/S6N5C/C5aWWe6dsrSR/EczUVtYuzq8i
fxE6Qy2mrZvZQP4iNNl/7bmRTGwnwj1RV1LP+GrGPBFWhTv8EGSdZ/vNF+Hq
4Xtl8+fXMxaLcCND3/nNskZ6/0VITYjfPyfvCWNJb59jt9+y7GLGeSKcvpYj
WbjxHM1fhMHNU7g2dVLyF6Gf9abTdiap7PoGEUIXJcyTiRHR/EXQ2KDz6nPh
UfKPR7+LuwQ/HcvIPx5R9vJj2y+TLzceIw+nllj+Q/uhF4+OK+dfrd2zjfzj
oRtyP2P9ogp2f7t43JZbMvX7wMeMefFoCTwiyNGpI/94aAqineJ06TyK47F8
7xVtmQUl5B+PmTarheWbT7L7S+Jx0/ZaZffZYsZ58fixYFZV5MAS8o/Hw47C
5LaXV8g/HsMOvG7aP+QAnf94JIsMiqRX9pJ/PIyVTIx1giR0/hPQJDqdsdZq
Pb3/Cdg165lHUeoO8k/AWlcJ94XHcfJPgJaDWOHp4FzyT4DePzPWyE5Mp/kn
YJPpjR1mLzaTfwLaJjkk9Bt1gPwTMGzkTtFgo33knwDlZm2ncI8t5J8A7sqR
exS+WNP8E5BrH8mp3pNK/gn4PbTHfMZob7YuTYBdjkv7j+/kU5mA4vJZ5YUy
BTT/BLzPLZIxqpGSfwLie7JeG7aVk38ipvsf6jbPfED+iZC4ZD4aI0/fB24i
zmTZ3baeTfPSS4S+sctQvYpHjJEIA7+Q7HPLaN52iXDznJdyJYzWeYl4t2Ld
Lr0cuh8/ER5Huy/8mU7nRZyIWpNAdVPeJfJPhKD5fb3ZTdpfSSLcQxx+xA4q
Iv9EmEa+2h/28hbNPxEWR7KtbW5dpPknYtMfaXb2rBzyT4TtfMhmD6gi/0SI
P1yPGr/4FfknwbgiR9bQ7TP5J0F9jJYq53Ub+SehcNKCoW+12sk/CeWLF15t
3fqF/JMga5bcdWUSvb92SQhLXHtIcVwpvf9JMNnbUTd3GH1v+EnYt9miOf1b
f/r5n4RrV7OHZ9rI0+8/SSjOGZMwO0iBvn9J8DrWaLakidbzkqDaPTu9xJu+
p9Ik3G9Jd+1poe9XZRKa/vHYsFe3H/38S0L3hyaHSo4K/fzrff4HMx3g8oH8
k3HKz+l680V6vxST8VlmicEzxVo6/8ng/Gdy5st48tFLxr9BZ18E7VpF5z8Z
8Y1LjkXp0vfGLhlKgzI/HQ66RvNPxuMKhZX5Q2mdn4zUwJGcLC86j+JkTAwK
mIn0pzT/ZMSOTakLXEHfC0kyfl+3tH02l96/vGQ4525qtx1zl+afDL7Amf9h
+EM6/8lQO/jPTJf8Zpp/Mp7yO3KFNfT7TGsy1o6JXmekfJH8xZiTEuTP4dL3
428x5Le8apSq5NN+iCHQuTP44Fo+45FiZFY4zz9uHkP7I4atJEI9dBm9/xPF
+L24Qe2stYDOixie7dnS/fPSGBuJUSlX7JrGi7z6P+OvO5k=
        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw1l3lcjOv7x0dRREpS1iRxLEmp0CF9lIpKi1Zt2vdl2mempqaU/ShbohBF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        "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
    AspectRatio->0.7692307692307692,
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0., 0},
    DisplayFunction->Identity,
    Frame->{{True, True}, {True, True}},
    FrameLabel->{{
       FormBox["\"Conc(nM)\"", TraditionalForm], None}, {
       FormBox["\"Datapoint\"", TraditionalForm], None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    LabelStyle->Directive[FontFamily -> "Helvetica"],
    Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotLabel->FormBox["\"Autocatalyst  Threshold\"", TraditionalForm],
    PlotRange->{{0., 519.}, {0, 5}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {0, 0}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw12HlcTekfB/CH/AhRZkxl7UpDsl0ZYx+PNLYsFxkROQqlmLlIReHIlmXq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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw92HlcTfn/B/AzxozGNpexROLM2LLEHdmVTppSZFzrhHDtSXJtCcVBQpa5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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw92XtcTVkbB/BNLsntvCSN65GoMSMnGYVkoyFUTumGypZcEjkRUZg9uZRU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        
        "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
    AspectRatio->0.7692307692307692,
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{True, True}, {True, True}},
    FrameLabel->{{
       FormBox["\"dnM/datapoint\"", TraditionalForm], None}, {
       FormBox["\"Datapoint\"", TraditionalForm], None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    LabelStyle->Directive[FontFamily -> "Helvetica"],
    Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotLabel->FormBox[
     "\"Autocatalyst  Helper Derivatives\"", TraditionalForm],
    PlotRange->{{0, 490.}, {-0.27225665256936793`, 0}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.05], 
       Scaled[0.02]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6582388880909643`*^9, 3.658238934738946*^9, 3.658252619798915*^9, 
   3.658252703774728*^9, 3.658253928583797*^9, 3.658254203686029*^9, 
   3.658254731401599*^9, 3.658254804460228*^9, 3.6582549056525917`*^9, 
   3.658255133224147*^9, {3.65826513101618*^9, 3.6582651369526043`*^9}, {
   3.658265758523307*^9, 3.6582657856699553`*^9}, 3.658266056164888*^9, 
   3.658277296698081*^9, 3.6582777970494957`*^9, 3.6583410265919*^9, {
   3.6583410681353817`*^9, 3.6583412036567173`*^9}, {3.6583412733735857`*^9, 
   3.658341405104211*^9}, {3.658341614933539*^9, 3.658341622574423*^9}, 
   3.6583428433035793`*^9, 3.658342938163424*^9, 3.658346057344057*^9, 
   3.6583514244226017`*^9, 3.658351544660448*^9, 3.658352571786889*^9, 
   3.6584269814483213`*^9, 3.658427036379738*^9, 3.658427085829857*^9, 
   3.6584271595303288`*^9, 3.658427190906823*^9, 3.6584272503076687`*^9, 
   3.6584957949520884`*^9, 3.6584958285663767`*^9, 3.658496220424283*^9, {
   3.658496364489097*^9, 3.658496391853513*^9}, 3.658496529774478*^9, 
   3.658497270287959*^9, 3.658500308366734*^9, 3.659211406704113*^9, 
   3.659901388887882*^9, 3.659901984569077*^9, 3.659902136379796*^9, 
   3.660329957005981*^9, 3.660330027075097*^9, 3.6603300716778927`*^9, 
   3.660929972943922*^9, 3.660930111517378*^9, 3.660937053767787*^9, 
   3.662492432696251*^9, 3.6624926841834908`*^9, 3.6624929703265657`*^9, 
   3.662493119518074*^9, 3.662493208011739*^9, 3.6624941723129807`*^9, {
   3.662494202896556*^9, 3.662494216267384*^9}, 3.662494301260385*^9, 
   3.662494348230192*^9, 3.662494389024797*^9, {3.662494491506569*^9, 
   3.662494537029373*^9}, 3.6630228677178802`*^9, {3.6630780350688972`*^9, 
   3.663078053983354*^9}, 3.663078093064183*^9, 3.663078149988883*^9, 
   3.6630785366915703`*^9, 3.6630789609931707`*^9, 3.663079030360364*^9, 
   3.663079226700268*^9, 3.663079616563393*^9, 3.663080302260708*^9, 
   3.663080553354383*^9, 3.709409541198586*^9, 3.7094096046785097`*^9, 
   3.709409706916438*^9, 3.7094099082376842`*^9, 3.71115255502043*^9, 
   3.711153016716421*^9, 3.7111532942106857`*^9, 3.711153623673584*^9, 
   3.711191033697525*^9, 3.711191569483955*^9, 3.7111916193387823`*^9, 
   3.711192784170209*^9, 3.711194048438571*^9, {3.7111940888525*^9, 
   3.711194106464959*^9}, {3.711194168424878*^9, 3.7111941919094267`*^9}, 
   3.711194490650522*^9, 3.711237150002706*^9, 3.711237417688922*^9, 
   3.711237498909214*^9, 3.711241082602804*^9, 3.711649793896229*^9, {
   3.711651049687969*^9, 3.7116510584006844`*^9}, 
   3.7116511972717*^9},ExpressionUUID->"c8c06684-cbc0-45bb-8269-d7a366920975"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "plotDataHelper", ",", "plotDataThreshold", ",", 
   "plotDataHelperDerivatives"}], "}"}]], "Input",
 CellChangeTimes->{{3.658238868438539*^9, 3.6582388872124577`*^9}, {
  3.658238979880093*^9, 3.658238983200301*^9}, {3.660930058653679*^9, 
  3.660930062950306*^9}, {3.663078497807562*^9, 
  3.663078498805566*^9}},ExpressionUUID->"3772e22e-071b-4850-832b-\
8afd6b817bc9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {{}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJxdWWuQlMUVHQkIQUtXQgSNJCMSgiC6RAkSJdyV1wILzL6fLLPv9+437/fM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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJxdWWmUlMUV7RBcDnqwRaIGl7QIiILaqIiKOA8QkL2ZYRb2nn2f6X1fPkWC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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJxdWWmQVNUVbokSyqjVZdAMBrHVEXFB24WoLOEg+96zMMPAMPTs+8zrfe9+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        "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
    AspectRatio->0.7692307692307692,
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0., 0},
    DisplayFunction->Identity,
    Frame->{{True, True}, {True, True}},
    FrameLabel->{{
       FormBox["\"Conc(nM)\"", TraditionalForm], None}, {
       FormBox["\"Datapoint\"", TraditionalForm], None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    LabelStyle->Directive[FontFamily -> "Helvetica"],
    Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotLabel->FormBox["\"Autocatalyst  Helper\"", TraditionalForm],
    PlotRange->{{0., 519.}, {0, 100}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {0, 0}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJxVWHk81Nv/nkSlupYSWq6mXZtkuZWkR6vSQmRJGPvOGAazmWmV1DctIlJD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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJxdWWdUk1m0jdgVEdTBPgbsHRGww1YE7EaKIoJ06RAINQQSZSxYsXeMHcaG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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw1mXdcU2cbhuOeUJzFHa2fe2DdVuQWB+JgOEDFEbYyA4Gwk2itolYNzopV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        "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
    AspectRatio->0.7692307692307692,
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0., 0},
    DisplayFunction->Identity,
    Frame->{{True, True}, {True, True}},
    FrameLabel->{{
       FormBox["\"Conc(nM)\"", TraditionalForm], None}, {
       FormBox["\"Datapoint\"", TraditionalForm], None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    LabelStyle->Directive[FontFamily -> "Helvetica"],
    Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotLabel->FormBox["\"Autocatalyst  Threshold\"", TraditionalForm],
    PlotRange->{{0., 519.}, {0, 5}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {0, 0}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {{}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw113tcz9cfB/Djsmlicr+s8W25NMa6IJI6uSY130Kh6INcstK3lFuxj6WU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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw92Hlczdn/B/BPMmPXtS8TLqORSJcsoXKslbHcEmpQN5Sk0S1UyPjYs19D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        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.004583333333333334], Thickness[Large], 
       PointBox[CompressedData["
1:eJw12XtcTVkbB/Atasjt5NpQr2NUYqQj5W5sFCLknlTOCCOh41ohNkKRHPfc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        
        "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
    AspectRatio->0.7692307692307692,
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    Frame->{{True, True}, {True, True}},
    FrameLabel->{{
       FormBox["\"dnM/datapoint\"", TraditionalForm], None}, {
       FormBox["\"Datapoint\"", TraditionalForm], None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImagePadding->All,
    LabelStyle->Directive[FontFamily -> "Helvetica"],
    Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          (Identity[#]& )[
           Part[#, 1]], 
          (Identity[#]& )[
           Part[#, 2]]}& )}},
    PlotLabel->FormBox[
     "\"Autocatalyst  Helper Derivatives\"", TraditionalForm],
    PlotRange->{{0, 490.}, {-0.3348705770857521, 0.0034680631179000443`}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6582388880909643`*^9, 3.658238934738946*^9, {3.658238987107373*^9, 
   3.658239008882634*^9}, 3.6582526200492992`*^9, 3.6582527039315653`*^9, 
   3.65825392874222*^9, 3.6582542038961287`*^9, 3.658254731581973*^9, 
   3.6582548046184883`*^9, 3.6582549058687677`*^9, 3.658255133377265*^9, {
   3.658265131075313*^9, 3.658265136992735*^9}, 3.658265785752273*^9, 
   3.658266056210002*^9, 3.658277296744927*^9, 3.6582777971048098`*^9, 
   3.658341026641775*^9, {3.658341068188128*^9, 3.658341203708604*^9}, {
   3.658341273428604*^9, 3.658341405147344*^9}, {3.658341614985297*^9, 
   3.658341622615992*^9}, 3.6583428433582067`*^9, 3.6583429382165213`*^9, 
   3.658346057396182*^9, 3.658351424506751*^9, 3.65835154472692*^9, 
   3.658352571856196*^9, 3.658426981503263*^9, 3.658427036438259*^9, 
   3.65842708586939*^9, 3.6584271595692673`*^9, 3.658427191004636*^9, 
   3.6584272503676853`*^9, 3.6584957950431213`*^9, 3.658495828619411*^9, 
   3.658496220488122*^9, {3.658496364544537*^9, 3.6584963919513187`*^9}, 
   3.6584965298748617`*^9, 3.6584972703381433`*^9, 3.658500308413045*^9, 
   3.6592114067673283`*^9, 3.6599013890060596`*^9, 3.6599019846731033`*^9, 
   3.659902136478211*^9, 3.660329957042224*^9, 3.6603300271111593`*^9, 
   3.660330071732547*^9, 3.660929972986081*^9, {3.6609300637998466`*^9, 
   3.660930075639926*^9}, 3.66093705382589*^9, 3.66249243275004*^9, 
   3.662492684256934*^9, 3.66249297042238*^9, 3.662493119621542*^9, 
   3.662493208119926*^9, 3.6624941723677387`*^9, {3.662494202988809*^9, 
   3.662494216365466*^9}, 3.662494301334042*^9, 3.6624943483339853`*^9, 
   3.6624943891034327`*^9, {3.6624944916023273`*^9, 3.662494537127644*^9}, 
   3.663022867771167*^9, {3.663078035136053*^9, 3.663078054048506*^9}, 
   3.663078093109645*^9, 3.663078150056408*^9, 3.6630785367493057`*^9, 
   3.6630789610604277`*^9, 3.663079030433578*^9, 3.6630792268194113`*^9, 
   3.6630796167760363`*^9, 3.663080302338601*^9, 3.663080553413055*^9, 
   3.709409541248876*^9, 3.7094096047506447`*^9, 3.709409706969741*^9, 
   3.7094099083722677`*^9, 3.711152555103979*^9, 3.711153016787219*^9, 
   3.7111532943030157`*^9, 3.7111536237257977`*^9, 3.7111910337603073`*^9, 
   3.711191569537446*^9, 3.711191619405684*^9, 3.711192784227688*^9, 
   3.711194048519442*^9, {3.711194088945443*^9, 3.711194106583199*^9}, {
   3.7111941685067244`*^9, 3.711194191989953*^9}, 3.711194490704083*^9, 
   3.7112371500672073`*^9, 3.711237417755816*^9, 3.711237499048213*^9, 
   3.7112410826918707`*^9, 3.7116497939987583`*^9, {3.7116510497820463`*^9, 
   3.711651058465899*^9}, 
   3.711651197330743*^9},ExpressionUUID->"727582ee-85c4-49d0-b0ac-\
146c1e9e5bf4"]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{813, 736},
WindowMargins->{{Automatic, 0}, {Automatic, 3}},
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 18, \
2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 304, 5, 30, "Text", "ExpressionUUID" -> \
"82ccb513-2073-4b96-a27a-901785837b97"],
Cell[CellGroupData[{
Cell[887, 29, 209, 4, 44, "Subsection", "ExpressionUUID" -> \
"ab971b2c-f52a-4373-8a41-45d92ff3f054"],
Cell[1099, 35, 424, 11, 32, "Input", "ExpressionUUID" -> \
"cb039ef8-c519-44e5-9fa7-d84d9715295c"],
Cell[1526, 48, 3203, 69, 306, "Input", "ExpressionUUID" -> \
"a92b2572-cc46-4eb5-a7f1-4e7773ea2e89"],
Cell[4732, 119, 1412, 30, 75, "Input", "ExpressionUUID" -> \
"d8d00205-bc39-4b99-8087-ac5a0e9dfe71"],
Cell[6147, 151, 781, 20, 75, "Input", "ExpressionUUID" -> \
"bf8e5671-d021-422f-8666-182ec7cb97ca"],
Cell[6931, 173, 1205, 27, 75, "Input", "ExpressionUUID" -> \
"a6ca6dfc-a89f-4470-bb31-8e823d1c8ec3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8173, 205, 205, 4, 44, "Subsection", "ExpressionUUID" -> \
"68393eb1-ea46-43a7-913b-3202929222bb"],
Cell[8381, 211, 249, 6, 32, "Input", "ExpressionUUID" -> \
"6a5a0f48-6ae3-45ad-828a-675ba719404d"],
Cell[8633, 219, 754, 15, 32, "Input", "ExpressionUUID" -> \
"baf9529e-b846-47dd-abdc-d83e8664b5a6"],
Cell[9390, 236, 724, 15, 32, "Input", "ExpressionUUID" -> \
"fde57c34-2a28-4d15-bf77-717135e25564"],
Cell[10117, 253, 826, 16, 32, "Input", "ExpressionUUID" -> \
"afb1a695-a8cb-4ff9-a79f-5330dc963fa1"],
Cell[10946, 271, 1299, 35, 54, "Input", "ExpressionUUID" -> \
"c595274d-e479-454f-bea9-4e9ad54a215d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12282, 311, 253, 4, 44, "Subsection", "ExpressionUUID" -> \
"57116881-009a-469b-8554-e5ab182e429f"],
Cell[12538, 317, 4714, 95, 369, "Input", "ExpressionUUID" -> \
"1819618b-cfc7-47cc-afa8-8e192f8d894f"],
Cell[17255, 414, 740, 16, 32, "Input", "ExpressionUUID" -> \
"d03990b6-f92b-4acc-9f9b-e8b98186e7bf"],
Cell[17998, 432, 723, 16, 32, "Input", "ExpressionUUID" -> \
"e1db8f04-26ba-48ba-84c6-33be5d8b3018"],
Cell[18724, 450, 795, 20, 54, "Input", "ExpressionUUID" -> \
"8a237cf5-ac59-4657-ba61-e65aed26991d"],
Cell[19522, 472, 867, 22, 96, "Input", "ExpressionUUID" -> \
"c1e8bd77-a1a1-4e1c-9fae-884ef365b634"],
Cell[20392, 496, 695, 16, 32, "Input", "ExpressionUUID" -> \
"257cf667-a1ad-4182-ab5c-71f0d799c9d9"],
Cell[21090, 514, 4087, 93, 369, "Input", "ExpressionUUID" -> \
"8b36b6f3-544e-4d41-9422-a0c36f0eba06"],
Cell[25180, 609, 434, 10, 54, "Input", "ExpressionUUID" -> \
"6426c8e6-032a-4069-bf99-86a569cda570"],
Cell[25617, 621, 1987, 37, 96, "Input", "ExpressionUUID" -> \
"20a68d1a-125e-4b5e-92aa-800b30b95723"],
Cell[27607, 660, 3504, 118, 75, "Input", "ExpressionUUID" -> \
"97e56326-d838-4307-b6f6-79c848023238"],
Cell[CellGroupData[{
Cell[31136, 782, 2177, 46, 243, "Input", "ExpressionUUID" -> \
"40f44ed4-2246-4a09-8d01-5038afe2aa06"],
Cell[33316, 830, 446, 11, 32, "Output", "ExpressionUUID" -> \
"2c744f97-d554-4afb-944a-54ff483a483c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33799, 846, 275, 7, 32, "Input", "ExpressionUUID" -> \
"5ae48608-3693-4fb6-9be1-e7ea899829a7"],
Cell[34077, 855, 1056, 19, 32, "Output", "ExpressionUUID" -> \
"163b0873-bf4b-4b97-9f36-bc31d8bf9d66"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35170, 879, 371, 8, 32, "Input", "ExpressionUUID" -> \
"892e20b0-aed2-4dfd-a7da-8703226c67ca"],
Cell[35544, 889, 1069, 18, 32, "Output", "ExpressionUUID" -> \
"5ed27675-9303-47b8-9191-b2d751bb0790"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36650, 912, 237, 6, 32, "Input", "ExpressionUUID" -> \
"497c027b-74d8-44ee-a4ee-bf12f8ef784d"],
Cell[36890, 920, 962, 17, 32, "Output", "ExpressionUUID" -> \
"2969fa11-3ac2-4043-8093-c623657dd280"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37901, 943, 220, 4, 44, "Subsection", "ExpressionUUID" -> \
"bcbd7000-2c08-460a-848e-5acc1a8b4285"],
Cell[38124, 949, 1873, 38, 96, "Input", "ExpressionUUID" -> \
"050b9f30-14f4-435c-968a-2171c24b0891"],
Cell[40000, 989, 654, 15, 32, "Input", "ExpressionUUID" -> \
"6f1b451e-30da-4290-8fbc-8137bd3d731f"],
Cell[40657, 1006, 641, 15, 32, "Input", "ExpressionUUID" -> \
"c9c14027-5c60-4a11-bca7-e28ffc563a9a"],
Cell[41301, 1023, 534, 15, 54, "Input", "ExpressionUUID" -> \
"d80e514d-9434-4714-996a-eaed5d502c60"],
Cell[41838, 1040, 2132, 46, 159, "Input", "ExpressionUUID" -> \
"9d7c3b30-ed4a-48c6-b83b-a331e36decfc"],
Cell[43973, 1088, 2087, 45, 159, "Input", "ExpressionUUID" -> \
"ad35ca82-1d27-4f87-912d-b953efbb2f4b"],
Cell[46063, 1135, 2119, 45, 180, "Input", "ExpressionUUID" -> \
"c9cab3d3-f667-46ef-b359-f2c859bf3133"],
Cell[48185, 1182, 2082, 45, 159, "Input", "ExpressionUUID" -> \
"38d6ed55-1aa7-4fac-a1f7-fb267a76d1c3"],
Cell[50270, 1229, 2134, 46, 159, "Input", "ExpressionUUID" -> \
"8c2706bf-ebce-4673-a4d9-3dddfafeb516"],
Cell[52407, 1277, 2113, 45, 180, "Input", "ExpressionUUID" -> \
"f82f8f41-23c6-4497-b002-13386af327da"],
Cell[CellGroupData[{
Cell[54545, 1326, 368, 8, 32, "Input", "ExpressionUUID" -> \
"6be72144-6e2b-4657-b4ed-54721aae4d95"],
Cell[54916, 1336, 66424, 1139, 185, "Output", "ExpressionUUID" -> \
"c8c06684-cbc0-45bb-8269-d7a366920975"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121377, 2480, 414, 9, 32, "Input", "ExpressionUUID" -> \
"3772e22e-071b-4850-832b-8afd6b817bc9"],
Cell[121794, 2491, 58856, 1014, 185, "Output", "ExpressionUUID" -> \
"727582ee-85c4-49d0-b0ac-146c1e9e5bf4"]
}, Open  ]]
}, Open  ]]
}
]
*)

